@@ -17,9 +17,10 @@ Formatting for tables.
 
 # isort: STDLIB
 import sys
+import uuid
 
 from .._errors import StratisCliEnginePropertyError, StratisCliPropertyNotFoundError
-from ._utils import fetch_property
+from ._utils import unpack_property
 
 # If the wcwidth package is not available the wcswidth function will not
 # be available. In that case, use the standard function len where wcswidth
@@ -61,7 +62,7 @@ def get_property(props, name, to_repr, default):
     :rtype: object
     """
     try:
-        return to_repr(fetch_property(props, name))
+        return to_repr(unpack_property(props, name))
     # An exception should only be raised if the property can not be obtained.
     # This requires either running against an interface that does not support
     # the property or the engine encountering an error getting the property,
@@ -162,3 +163,10 @@ def print_table(column_headings, row_entries, alignment, file=sys.stdout):
     for row, row_widths in zip(row_entries, cell_widths):
         _print_row(file, row, row_widths, column_widths, alignment)
         print(file=file)
+
+
+def to_hyphenated(mo_uuid):
+    """
+    Convert uuid string to hyphenated format
+    """
+    return str(uuid.UUID(mo_uuid))
